Identification
=============

The identification module provides tools for dynamic parameter identification of robots.

**New in v0.3.0:**
- ``solve_with_custom_solver()`` method with advanced solving options
- Support for regularization (L1, L2, Elastic Net)
- Physical constraint enforcement (e.g., positive masses/inertias)
- Enhanced configuration management with modular design

base_identification
------------------
.. automodule:: figaroh.identification.base_identification
   :members:
   :undoc-members:
   :show-inheritance:

identification_tools
------------------
.. automodule:: figaroh.identification.identification_tools
   :members:
   :undoc-members:
   :show-inheritance:

Configuration Management (New in v0.3.0)
----------------------------------------
.. automodule:: figaroh.identification.config
   :members:
   :undoc-members:
   :show-inheritance:

Parameter Management (New in v0.3.0)
------------------------------------
.. automodule:: figaroh.identification.parameter
   :members:
   :undoc-members:
   :show-inheritance:
